[CalendarServer-changes] [5374] CalendarServer/trunk/twistedcaldav/mail.py

source_changes at macosforge.org source_changes at macosforge.org
Mon Mar 22 12:47:32 PDT 2010


Revision: 5374
          http://trac.macosforge.org/projects/calendarserver/changeset/5374
Author:   sagen at apple.com
Date:     2010-03-22 12:47:31 -0700 (Mon, 22 Mar 2010)
Log Message:
-----------
Store the "mailto:" portion of the IMIP attendee in the mail gateway tokens database.

Modified Paths:
--------------
    CalendarServer/trunk/twistedcaldav/mail.py

Modified: CalendarServer/trunk/twistedcaldav/mail.py
===================================================================
--- CalendarServer/trunk/twistedcaldav/mail.py	2010-03-20 22:37:44 UTC (rev 5373)
+++ CalendarServer/trunk/twistedcaldav/mail.py	2010-03-22 19:47:31 UTC (rev 5374)
@@ -804,15 +804,15 @@
         if method != "REPLY":
             # Invites and cancellations:
 
             # Reuse or generate a token based on originator, recipient, and
             # event uid
-            token = self.db.getToken(originator, recipient, icaluid)
+            token = self.db.getToken(originator, toAddr, icaluid)
             if token is None:
-                token = self.db.createToken(originator, recipient, icaluid)
-                self.log_debug("Mail gateway created token %s for %s (originator), %s (recipient) and %s (icaluid)" % (token, originator, recipient, icaluid))
+                token = self.db.createToken(originator, toAddr, icaluid)
+                self.log_debug("Mail gateway created token %s for %s (originator), %s (recipient) and %s (icaluid)" % (token, originator, toAddr, icaluid))
                 inviteState = "new"
             else:
-                self.log_debug("Mail gateway reusing token %s for %s (originator), %s (recipient) and %s (icaluid)" % (token, originator, recipient, icaluid))
+                self.log_debug("Mail gateway reusing token %s for %s (originator), %s (recipient) and %s (icaluid)" % (token, originator, toAddr, icaluid))
                 inviteState = "update"
 
             fullServerAddress = settings['Address']
-------------- next part --------------
@@ -804,15 +804,15 @@
             # Invites and cancellations:
 
-            # Reuse or generate a token based on originator, recipient, and
+            # Reuse or generate a token based on originator, toAddr, and
             # event uid
An HTML attachment was scrubbed...
URL: <http://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20100322/64098183/attachment.html>


More information about the calendarserver-changes mailing list